import { NextFunction, Request, Response } from 'express';
import { BaseController } from "./controllers/baseController";
import { AuthResponse } from "./models/authResponse";
import { Request as XRequest } from './models/request';
import { Endpoint } from './models/endpoint';
/**
 * Bootstraps the whole application.
 * @param params Params to assist with the bootstrapping process.
 */
export declare function bootstrap(params: {
    /**
     * The base route for all endpoints - for example: /api/v1
     */
    base?: string;
    /**
     * List of controllers to be used throughout the application.
     */
    controllers: typeof BaseController[];
    /**
     * Method to call while performing authentication and authorization on different routes.
     */
    authCallback?: (req: XRequest, endpoint: Endpoint) => AuthResponse;
}): (req: Request, res: Response, next: NextFunction) => Response<any> | undefined;
